[longomatch] The VideoWindow widget can be Disabled now, showing an 'Unavailable' text for viewports not connecte
- From: Andoni Morales Alastruey <amorales src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [longomatch] The VideoWindow widget can be Disabled now, showing an 'Unavailable' text for viewports not connecte
- Date: Tue, 31 Mar 2015 17:36:41 +0000 (UTC)
commit 528e5d9085c69e0c2d2dd6b0b0de49d3f7d11112
Author: Xavi Artigas <xartigas fluendo com>
Date: Fri Mar 27 15:19:00 2015 +0100
The VideoWindow widget can be Disabled now, showing an 'Unavailable' text for viewports not connected to
any stream.
LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs | 7 ++
.../gtk-gui/LongoMatch.Gui.VideoWindow.cs | 67 ++++++++++++-------
LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic | 22 ++++++-
3 files changed, 68 insertions(+), 28 deletions(-)
---
diff --git a/LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs b/LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs
index 1a2a2c8..fe910aa 100644
--- a/LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs
+++ b/LongoMatch.GUI.Multimedia/Gui/VideoWindow.cs
@@ -109,6 +109,13 @@ namespace LongoMatch.Gui
frame.Ratio = value;
}
}
+
+ public bool Enabled {
+ set {
+ videoeventbox.Visible = value;
+ disabledtext.Visible = !value;
+ }
+ }
}
}
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic b/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
index 2becd73..d304922 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
@@ -920,12 +920,28 @@
<property name="MemberName" />
<property name="Visible">False</property>
<child>
- <widget class="Gtk.EventBox" id="videoeventbox">
+ <widget class="Gtk.HBox" id="totalbox">
<property name="MemberName" />
<child>
- <placeholder />
+ <widget class="Gtk.EventBox" id="videoeventbox">
+ <property name="MemberName" />
+ </widget>
+ <packing>
+ <property name="Position">0</property>
+ <property name="AutoSize">False</property>
+ </packing>
+ </child>
+ <child>
+ <widget class="Gtk.Label" id="disabledtext">
+ <property name="MemberName" />
+ <property name="LabelProp" translatable="yes">Unavailable</property>
+ </widget>
+ <packing>
+ <property name="Position">1</property>
+ <property name="AutoSize">False</property>
+ </packing>
</child>
</widget>
</child>
</widget>
-</stetic-interface>
\ No newline at end of file
+</stetic-interface>
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.VideoWindow.cs
b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.VideoWindow.cs
index 0cb0523..a17a5dc 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.VideoWindow.cs
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.VideoWindow.cs
@@ -1,25 +1,42 @@
-
-// This file has been generated by the GUI designer. Do not modify.
-namespace LongoMatch.Gui
-{
- public partial class VideoWindow
- {
- private global::Gtk.EventBox videoeventbox;
-
- protected virtual void Build ()
- {
- global::Stetic.Gui.Initialize (this);
- // Widget LongoMatch.Gui.VideoWindow
- global::Stetic.BinContainer.Attach (this);
- this.Name = "LongoMatch.Gui.VideoWindow";
- // Container child LongoMatch.Gui.VideoWindow.Gtk.Container+ContainerChild
- this.videoeventbox = new global::Gtk.EventBox ();
- this.videoeventbox.Name = "videoeventbox";
- this.Add (this.videoeventbox);
- if ((this.Child != null)) {
- this.Child.ShowAll ();
- }
- this.Hide ();
- }
- }
-}
+
+// This file has been generated by the GUI designer. Do not modify.
+namespace LongoMatch.Gui
+{
+ public partial class VideoWindow
+ {
+ private global::Gtk.HBox totalbox;
+
+ private global::Gtk.EventBox videoeventbox;
+
+ private global::Gtk.Label disabledtext;
+
+ protected virtual void Build ()
+ {
+ global::Stetic.Gui.Initialize (this);
+ // Widget LongoMatch.Gui.VideoWindow
+ global::Stetic.BinContainer.Attach (this);
+ this.Name = "LongoMatch.Gui.VideoWindow";
+ // Container child LongoMatch.Gui.VideoWindow.Gtk.Container+ContainerChild
+ this.totalbox = new global::Gtk.HBox ();
+ this.totalbox.Name = "totalbox";
+ // Container child totalbox.Gtk.Box+BoxChild
+ this.videoeventbox = new global::Gtk.EventBox ();
+ this.videoeventbox.Name = "videoeventbox";
+ this.totalbox.Add (this.videoeventbox);
+ global::Gtk.Box.BoxChild w1 = ((global::Gtk.Box.BoxChild)(this.totalbox
[this.videoeventbox]));
+ w1.Position = 0;
+ // Container child totalbox.Gtk.Box+BoxChild
+ this.disabledtext = new global::Gtk.Label ();
+ this.disabledtext.Name = "disabledtext";
+ this.disabledtext.LabelProp = global::Mono.Unix.Catalog.GetString ("Unavailable");
+ this.totalbox.Add (this.disabledtext);
+ global::Gtk.Box.BoxChild w2 = ((global::Gtk.Box.BoxChild)(this.totalbox
[this.disabledtext]));
+ w2.Position = 1;
+ this.Add (this.totalbox);
+ if ((this.Child != null)) {
+ this.Child.ShowAll ();
+ }
+ this.Hide ();
+ }
+ }
+}